@@ -141,7 +141,7 @@ change_numbering_order (GSimpleAction *action,
             dialog->selection = nautilus_batch_rename_dialog_sort (dialog->selection,
                                                                    sorts_constants[i].sort_mode,
                                                                    dialog->create_date);
-          break;
+            break;
         }
     }
 
@@ -636,9 +636,13 @@ create_arrow_row_for_label (NautilusBatchRenameDialog *dialog,
     g_object_set_data (G_OBJECT (row), "show-separator", GINT_TO_POINTER (show_separator));
 
     if (gtk_widget_get_direction (row) == GTK_TEXT_DIR_RTL)
+    {
         icon = gtk_label_new ("←");
+    }
     else
+    {
         icon = gtk_label_new ("→");
+    }
 
     gtk_label_set_xalign (GTK_LABEL (icon), 1.0);
     gtk_widget_set_hexpand (icon, FALSE);
@@ -943,7 +947,7 @@ update_listbox (NautilusBatchRenameDialog *dialog)
         new_name = l1->data;
 
         gtk_label_set_label (label, new_name->str);
-        gtk_widget_set_tooltip_text(GTK_WIDGET (label), new_name->str);
+        gtk_widget_set_tooltip_text (GTK_WIDGET (label), new_name->str);
 
         if (g_strcmp0 (new_name->str, "") == 0)
         {
@@ -957,7 +961,7 @@ update_listbox (NautilusBatchRenameDialog *dialog)
         file = NAUTILUS_FILE (l1->data);
 
         old_name = nautilus_file_get_name (file);
-        gtk_widget_set_tooltip_text(GTK_WIDGET (label), old_name);
+        gtk_widget_set_tooltip_text (GTK_WIDGET (label), old_name);
 
         if (dialog->mode == NAUTILUS_BATCH_RENAME_DIALOG_FORMAT)
         {
@@ -1033,7 +1037,7 @@ update_listbox (NautilusBatchRenameDialog *dialog)
     }
 }
 
-void
+static void
 check_conflict_for_files (NautilusBatchRenameDialog *dialog,
                           NautilusDirectory         *directory,
                           GList                     *files)
@@ -1175,9 +1179,9 @@ file_names_list_has_duplicates_finish (NautilusBatchRenameDialog  *self,
                                        GAsyncResult               *res,
                                        GError                    **error)
 {
-  g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
+    g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
 
-  return g_task_propagate_boolean (G_TASK (res), error);
+    return g_task_propagate_boolean (G_TASK (res), error);
 }
 
 static void
@@ -1298,11 +1302,10 @@ file_names_list_has_duplicates_async_thread (GTask        *task,
         }
 
         g_mutex_unlock (&task_data->wait_ready_mutex);
-
     }
 
-  g_task_return_boolean (task, TRUE);
-  nautilus_directory_list_free (directories);
+    g_task_return_boolean (task, TRUE);
+    nautilus_directory_list_free (directories);
 }
 
 static void
@@ -1340,7 +1343,7 @@ file_names_list_has_duplicates_async (NautilusBatchRenameDialog *dialog,
     dialog->checking_conflicts = TRUE;
 
     task = g_task_new (dialog, dialog->conflict_cancellable, callback, user_data);
-    task_data = g_new0(CheckConflictsData, 1);
+    task_data = g_new0 (CheckConflictsData, 1);
     g_task_set_task_data (task, task_data, destroy_conflicts_task_data);
     g_task_run_in_thread (task, file_names_list_has_duplicates_async_thread);
 }
@@ -1412,19 +1415,19 @@ have_unallowed_character (NautilusBatchRenameDialog *dialog)
     if (have_unallowed_character_slash)
     {
         gtk_label_set_label (GTK_LABEL (dialog->conflict_label),
-                             "\"/\" is an unallowed character");
+                             "“/” is an unallowed character");
     }
 
     if (have_unallowed_character_dot)
     {
         gtk_label_set_label (GTK_LABEL (dialog->conflict_label),
-                             "\".\" is an unallowed file name");
+                             "“.” is an unallowed file name");
     }
 
     if (have_unallowed_character_dotdot)
     {
         gtk_label_set_label (GTK_LABEL (dialog->conflict_label),
-                             "\"..\" is an unallowed file name");
+                             "“..” is an unallowed file name");
     }
 
     if (have_unallowed_character_slash || have_unallowed_character_dot || have_unallowed_character_dotdot)
@@ -1459,7 +1462,7 @@ numbering_tag_is_some_added (NautilusBatchRenameDialog *self)
         tag_data = g_hash_table_lookup (self->tag_info_table, tag_text_representation);
         if (tag_data->set)
         {
-          return TRUE;
+            return TRUE;
         }
     }
 
@@ -1493,11 +1496,11 @@ update_display_text (NautilusBatchRenameDialog *dialog)
 
     if (!numbering_tag_is_some_added (dialog))
     {
-        gtk_revealer_set_reveal_child(GTK_REVEALER(dialog->numbering_revealer), FALSE);
+        gtk_revealer_set_reveal_child (GTK_REVEALER (dialog->numbering_revealer), FALSE);
     }
     else
     {
-        gtk_revealer_set_reveal_child(GTK_REVEALER(dialog->numbering_revealer), TRUE);
+        gtk_revealer_set_reveal_child (GTK_REVEALER (dialog->numbering_revealer), TRUE);
     }
 
     dialog->new_names = batch_rename_dialog_get_new_names (dialog);
@@ -1801,7 +1804,7 @@ typedef enum
     TEXT_WAS_INSERTED
 } TextChangedMode;
 
-static GList*
+static GList *
 get_tags_intersecting_sorted (NautilusBatchRenameDialog *self,
                               gint                       start_position,
                               gint                       end_position,
@@ -1842,7 +1845,6 @@ get_tags_intersecting_sorted (NautilusBatchRenameDialog *self,
                                                  start_position < tag_end_position;
                 selection_intersects_tag_end = FALSE;
                 tag_is_contained_in_selection = FALSE;
-
             }
             if (selection_intersects_tag_end || selection_intersects_tag_start || tag_is_contained_in_selection)
             {
@@ -1957,7 +1959,7 @@ on_insert_text (GtkEditable *editable,
     g_autoptr (GList) intersecting_tags = NULL;
 
     self = NAUTILUS_BATCH_RENAME_DIALOG (user_data);
-    start_position = *(int *)position;
+    start_position = *(int *) position;
     end_position = start_position + g_utf8_strlen (new_text, -1);
     intersecting_tags = get_tags_intersecting_sorted (self, start_position,
                                                       end_position, TEXT_WAS_INSERTED);
@@ -1977,7 +1979,7 @@ on_insert_text (GtkEditable *editable,
 static void
 file_names_widget_entry_on_changed (NautilusBatchRenameDialog *self)
 {
-   update_display_text (self);
+    update_display_text (self);
 }
 
 static void
@@ -2100,6 +2102,7 @@ nautilus_batch_rename_dialog_new (GList             *selection,
     GString *dialog_title;
     GList *l;
     gboolean all_targets_are_folders;
+    gboolean all_targets_are_regular_files;
 
     dialog = g_object_new (NAUTILUS_TYPE_BATCH_RENAME_DIALOG, "use-header-bar", TRUE, NULL);
 
@@ -2120,19 +2123,44 @@ nautilus_batch_rename_dialog_new (GList             *selection,
         }
     }
 
+    all_targets_are_regular_files = TRUE;
+    for (l = selection; l != NULL; l = l->next)
+    {
+        if (!nautilus_file_is_regular_file (NAUTILUS_FILE (l->data)))
+        {
+            all_targets_are_regular_files = FALSE;
+            break;
+        }
+    }
+
     dialog_title = g_string_new ("");
     if (all_targets_are_folders)
     {
         g_string_append_printf (dialog_title,
-                                ngettext ("Rename %d Folder", "Rename %d Folders", g_list_length (selection)),
+                                ngettext ("Rename %d Folder",
+                                          "Rename %d Folders",
+                                          g_list_length (selection)),
+                                g_list_length (selection));
+    }
+    else if (all_targets_are_regular_files)
+    {
+        g_string_append_printf (dialog_title,
+                                ngettext ("Rename %d File",
+                                          "Rename %d Files",
+                                          g_list_length (selection)),
                                 g_list_length (selection));
     }
     else
     {
         g_string_append_printf (dialog_title,
-                                ngettext ("Rename %d File", "Rename %d Files", g_list_length (selection)),
+                                /* To translators: %d is the total number of files and folders.
+                                 * Singular case of the string is never used */
+                                ngettext ("Rename %d File and Folder",
+                                          "Rename %d Files and Folders",
+                                          g_list_length (selection)),
                                 g_list_length (selection));
     }
+
     gtk_window_set_title (GTK_WINDOW (dialog), dialog_title->str);
 
     add_tag (dialog, metadata_tags_constants[ORIGINAL_FILE_NAME]);
