@@ -37,6 +37,9 @@
 #include "nautilus-file-undo-manager.h"
 #include "nautilus-toolbar-menu-sections.h"
 
+#include "animation/ide-box-theatric.h"
+#include "animation/egg-animation.h"
+
 #include <glib/gi18n.h>
 #include <math.h>
 
@@ -44,6 +47,9 @@
 #define NEEDS_ATTENTION_ANIMATION_TIMEOUT 2000 /*ms */
 #define REMOVE_FINISHED_OPERATIONS_TIEMOUT 3 /*s */
 
+#define ANIMATION_X_GROW 30
+#define ANIMATION_Y_GROW 30
+
 typedef enum
 {
     NAUTILUS_NAVIGATION_DIRECTION_NONE,
@@ -184,78 +190,10 @@ fill_menu (NautilusWindow *window,
     }
 }
 
-/* adapted from gtk/gtkmenubutton.c */
-static void
-menu_position_func (GtkMenu   *menu,
-                    gint      *x,
-                    gint      *y,
-                    gboolean  *push_in,
-                    GtkWidget *widget)
-{
-    GtkWidget *toplevel;
-    GtkRequisition menu_req;
-    GdkRectangle monitor;
-    gint monitor_num;
-    GdkScreen *screen;
-    GdkWindow *window;
-    GtkAllocation allocation;
-
-    /* Set the dropdown menu hint on the toplevel, so the WM can omit the top side
-     * of the shadows.
-     */
-    toplevel = gtk_widget_get_toplevel (GTK_WIDGET (menu));
-    gtk_window_set_type_hint (GTK_WINDOW (toplevel), GDK_WINDOW_TYPE_HINT_DROPDOWN_MENU);
-
-    window = gtk_widget_get_window (widget);
-    screen = gtk_widget_get_screen (GTK_WIDGET (menu));
-    monitor_num = gdk_screen_get_monitor_at_window (screen, window);
-    if (monitor_num < 0)
-    {
-        monitor_num = 0;
-    }
-
-    gdk_screen_get_monitor_workarea (screen, monitor_num, &monitor);
-    gtk_widget_get_preferred_size (GTK_WIDGET (menu), &menu_req, NULL);
-    gtk_widget_get_allocation (widget, &allocation);
-    gdk_window_get_origin (window, x, y);
-
-    *x += allocation.x;
-    *y += allocation.y;
-
-    if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
-    {
-        *x -= MAX (menu_req.width - allocation.width, 0);
-    }
-    else
-    {
-        *x += MAX (allocation.width - menu_req.width, 0);
-    }
-
-    if ((*y + allocation.height + menu_req.height) <= monitor.y + monitor.height)
-    {
-        *y += allocation.height;
-    }
-    else if ((*y - menu_req.height) >= monitor.y)
-    {
-        *y -= menu_req.height;
-    }
-    else if (monitor.y + monitor.height - (*y + allocation.height) > *y)
-    {
-        *y += allocation.height;
-    }
-    else
-    {
-        *y -= menu_req.height;
-    }
-
-    *push_in = FALSE;
-}
-
 static void
 show_menu (NautilusToolbar *self,
            GtkWidget       *widget,
-           guint            button,
-           guint32          event_time)
+           const GdkEvent  *event)
 {
     NautilusWindow *window;
     GtkWidget *menu;
@@ -289,9 +227,10 @@ show_menu (NautilusToolbar *self,
     }
 
     gtk_menu_attach_to_widget (GTK_MENU (menu), GTK_WIDGET (window), NULL);
-    gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-                    (GtkMenuPositionFunc) menu_position_func, widget,
-                    button, event_time);
+    gtk_menu_popup_at_widget (GTK_MENU (menu), widget,
+                              GDK_GRAVITY_SOUTH_WEST,
+                              GDK_GRAVITY_NORTH_WEST,
+                              event);
 }
 
 #define MENU_POPUP_TIMEOUT 1200
@@ -300,11 +239,13 @@ typedef struct
 {
     NautilusToolbar *self;
     GtkWidget *widget;
+    GdkEvent *event;
 } ScheduleMenuData;
 
 static void
 schedule_menu_data_free (ScheduleMenuData *data)
 {
+    gdk_event_free (data->event);
     g_slice_free (ScheduleMenuData, data);
 }
 
@@ -313,10 +254,12 @@ popup_menu_timeout_cb (gpointer user_data)
 {
     ScheduleMenuData *data = user_data;
 
-    show_menu (data->self, data->widget,
-               1, gtk_get_current_event_time ());
+    show_menu (data->self, data->widget, data->event);
 
-    return FALSE;
+    /* Need to also reset the ID here. */
+    unschedule_menu_popup_timeout (data->self);
+
+    return G_SOURCE_REMOVE;
 }
 
 static void
@@ -331,7 +274,8 @@ unschedule_menu_popup_timeout (NautilusToolbar *self)
 
 static void
 schedule_menu_popup_timeout (NautilusToolbar *self,
-                             GtkWidget       *widget)
+                             GtkWidget       *widget,
+                             GdkEvent        *event)
 {
     ScheduleMenuData *data;
 
@@ -341,28 +285,32 @@ schedule_menu_popup_timeout (NautilusToolbar *self,
     data = g_slice_new0 (ScheduleMenuData);
     data->self = self;
     data->widget = widget;
+    data->event = gdk_event_copy (event);
 
     self->popup_timeout_id = g_timeout_add_full (G_PRIORITY_DEFAULT, MENU_POPUP_TIMEOUT,
                                                  popup_menu_timeout_cb, data,
                                                  (GDestroyNotify) schedule_menu_data_free);
 }
 static gboolean
-navigation_button_press_cb (GtkButton      *button,
-                            GdkEventButton *event,
-                            gpointer        user_data)
+navigation_button_press_cb (GtkButton *button,
+                            GdkEvent  *event,
+                            gpointer   user_data)
 {
     NautilusToolbar *self = user_data;
+    GdkEventButton *button_event;
 
-    if (event->button == 3)
+    button_event = (GdkEventButton *) event;
+
+    if (button_event->button == 3)
     {
         /* right click */
-        show_menu (self, GTK_WIDGET (button), event->button, event->time);
+        show_menu (self, GTK_WIDGET (button), event);
         return TRUE;
     }
 
-    if (event->button == 1)
+    if (button_event->button == 1)
     {
-        schedule_menu_popup_timeout (self, GTK_WIDGET (button));
+        schedule_menu_popup_timeout (self, GTK_WIDGET (button), event);
     }
 
     return FALSE;
@@ -632,8 +580,32 @@ update_operations (NautilusToolbar *self)
          * property set. */
         if (gtk_widget_is_visible (GTK_WIDGET (self)))
         {
-            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->operations_button),
-                                          TRUE);
+            GtkAllocation rect;
+            IdeBoxTheatric *theatric;
+
+            gtk_widget_get_allocation (GTK_WIDGET (self->operations_button), &rect);
+            theatric = g_object_new (IDE_TYPE_BOX_THEATRIC,
+                                     "alpha", 0.9,
+                                     "background", "#fdfdfd",
+                                     "target", self->operations_button,
+                                     "height", rect.height,
+                                     "width", rect.width,
+                                     "x", rect.x,
+                                     "y", rect.y,
+                                     NULL);
+
+            egg_object_animate_full (theatric,
+                                     EGG_ANIMATION_EASE_IN_CUBIC,
+                                     250,
+                                     gtk_widget_get_frame_clock (GTK_WIDGET (self->operations_button)),
+                                     g_object_unref,
+                                     theatric,
+                                     "x", rect.x - ANIMATION_X_GROW,
+                                     "width", rect.width + (ANIMATION_X_GROW * 2),
+                                     "y", rect.y - ANIMATION_Y_GROW,
+                                     "height", rect.height + (ANIMATION_Y_GROW * 2),
+                                     "alpha", 0.0,
+                                     NULL);
         }
     }
 
@@ -1223,6 +1195,18 @@ nautilus_toolbar_set_active_slot (NautilusToolbar    *toolbar,
     }
 }
 
+gboolean
+nautilus_toolbar_is_menu_visible (NautilusToolbar *self)
+{
+    GtkPopover *popover;
+
+    g_return_val_if_fail (NAUTILUS_IS_TOOLBAR (self), FALSE);
+
+    popover = GTK_POPOVER (gtk_menu_button_get_popover (GTK_MENU_BUTTON (self->view_button)));
+
+    return gtk_widget_is_visible (GTK_WIDGET (popover));
+}
+
 gboolean
 nautilus_toolbar_is_operations_button_active (NautilusToolbar *self)
 {
